@@ -1,7 +1,7 @@
 #!@@PERL@@
-# $Id: show_configuration.pl,v 1.7 2005/02/22 20:50:28 smsimms Exp $
+# $Id: show_configuration.pl,v 1.7.4.2 2009-08-17 17:39:58 devrim Exp $
 # Author: Christopher Browne
-# Copyright 2004 Afilias Canada
+# Copyright 2004-2009 Afilias Canada
 
 # This script simply displays an overview of node configuration
 # for a given SLONY node set
@@ -40,7 +40,7 @@ if ($ENV{"SLONYSET"}) {
 print qq{
 Slony-I Cluster: $CLUSTER_NAME
 Logs stored under $LOGDIR
-Slony Binaries in: @@PGBINDIR@@
+Slony Binaries in: @@SLONBINDIR@@
 };
 if ($APACHE_ROTATOR) {
   print "Rotating logs using Apache Rotator: $APACHE_ROTATOR\n";
